<?php

# FitGallery 0.93
# (C) Copyright  Omar Lpez 'pollo', Enrique D. Bosch 'presi'
# http://fitgallery.presi.org
#
# scan dir

#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
#    http://www.gnu.org/licenses/gpl.html

if ($dirgal=='' || $file=='') exit();

$mtime=filemtime("$dirgal/$file");
$handledir=opendir("$dirgal/$file/$dirimgs");
$primero='x';
while (($fileimgs = readdir($handledir))!==false)
  {
    if ($fileimgs != '.' && $fileimgs != '..')
     {
       $itemf="$dirgal/$file/$dirimgs/$fileimgs";
       if (is_readable($itemf))
       {
         if ($primero == 'x') $primero=$fileimgs;
         $subtotal += filesize($itemf);
         $numimgs += 1;
       }
     }
  }

?>
